@@ -4,7 +4,7 @@
 import click
 import yaml
 
-from servicecatalog_puppet import cli_commands
+from . import cli_commands
 
 
 @click.group()
@@ -29,6 +29,13 @@ def deploy(f, single_account, num_workers):
     cli_commands.deploy(f, num_workers)
 
 
+@cli.command()
+@click.argument('f', type=click.File())
+@click.option('--single-account', default=None)
+def graph(f, single_account):
+    cli_commands.graph(f)
+
+
 @cli.command()
 @click.argument('f', type=click.File())
 def dry_run(f):
@@ -192,5 +199,11 @@ def set_config_value(name, value, type=bool):
     cli_commands.set_config_value(name, value)
 
 
+@cli.command()
+@click.argument('execution_id')
+def export_puppet_pipeline_logs(execution_id):
+    cli_commands.export_puppet_pipeline_logs(execution_id)
+
+
 if __name__ == "__main__":
     cli()
