@@ -323,6 +323,7 @@ class ProvisionProductTask(PuppetTask):
     worker_timeout = luigi.IntParameter(default=0, significant=False)
     ssm_param_outputs = luigi.ListParameter(default=[], significant=False)
     should_use_sns = luigi.Parameter(significant=False, default=False)
+    should_use_product_plans = luigi.Parameter(significant=False, default=False)
     requested_priority = luigi.Parameter(significant=False, default=0)
 
     try_count = 1
@@ -525,19 +526,34 @@ class ProvisionProductTask(PuppetTask):
                                 )
 
                     if provisioned_product_id:
-                        provisioned_product_id = aws.provision_product_with_plan(
-                            service_catalog,
-                            self.launch_name,
-                            self.account_id,
-                            self.region,
-                            product_id,
-                            version_id,
-                            self.puppet_account_id,
-                            path_id,
-                            params_to_use,
-                            self.version,
-                            self.should_use_sns,
-                        )
+                        if self.should_use_product_plans:
+                            provisioned_product_id = aws.provision_product_with_plan(
+                                service_catalog,
+                                self.launch_name,
+                                self.account_id,
+                                self.region,
+                                product_id,
+                                version_id,
+                                self.puppet_account_id,
+                                path_id,
+                                params_to_use,
+                                self.version,
+                                self.should_use_sns,
+                            )
+                        else:
+                            provisioned_product_id = aws.update_provisioned_product(
+                                service_catalog,
+                                self.launch_name,
+                                self.account_id,
+                                self.region,
+                                product_id,
+                                version_id,
+                                self.puppet_account_id,
+                                path_id,
+                                params_to_use,
+                                self.version,
+                            )
+
                     else:
                         provisioned_product_id = aws.provision_product(
                             service_catalog,
